This is an adaptation of a Debian patch to qemu that allows a passed-through
SLIC table with -acpitable to work both with SeaBIOS and OVMF on qemu 2.4.1

--- qemu-2.4.1/hw/acpi/core.c	2015-11-03 20:01:31.000000000 +0000
+++ ../qemu-2.4.1/hw/acpi/core.c	2015-11-23 14:25:39.306680115 +0000
@@ -79,6 +79,8 @@
     return (-sum) & 0xff;
 }
 
+char slic_table_oemid[6 + 4 + 4];
+int slic_table_exists = 0;
 
 /* Install a copy of the ACPI table specified in @blob.
  *
@@ -227,6 +229,11 @@
     /* recalculate checksum */
     ext_hdr->checksum = acpi_checksum((const char unsigned *)ext_hdr +
                                       ACPI_TABLE_PFX_SIZE, acpi_payload_size);
+
+    if (memcmp(ext_hdr->sig, "SLIC", 4) == 0) {
+       slic_table_exists = 1;
+       memcpy(slic_table_oemid, ext_hdr->oem_id, 6 + 4 + 4);
+    }
 }
 
 void acpi_table_add(const QemuOpts *opts, Error **errp)
--- qemu-2.4.1/hw/acpi/aml-build.c	2015-11-03 20:01:31.000000000 +0000
+++ ../qemu-2.4.1/hw/acpi/aml-build.c	2015-11-21 23:36:07.333790670 +0000
@@ -1135,6 +1135,9 @@
     return var;
 }
 
+extern char slic_table_oemid[];
+extern int slic_table_exists;
+
 void
 build_header(GArray *linker, GArray *table_data,
              AcpiTableHeader *h, const char *sig, int len, uint8_t rev)
@@ -1148,6 +1151,10 @@
     h->oem_revision = cpu_to_le32(1);
     memcpy(h->asl_compiler_id, ACPI_BUILD_APPNAME4, 4);
     h->asl_compiler_revision = cpu_to_le32(1);
+    if ((memcmp(sig, "RSDT", 4) == 0 || memcmp(sig, "FACP", 4) == 0) && slic_table_exists) {
+      /* for win7: OEM info in RSDT and SLIC should be the same */
+      memcpy(h->oem_id, slic_table_oemid, 6 + 4 + 4);
+    }
     h->checksum = 0;
     /* Checksum to be filled in by Guest linker */
     bios_linker_loader_add_checksum(linker, ACPI_BUILD_TABLE_FILE,
